@@ -1,3 +1,4 @@
+# encoding: utf8
 from __future__ import print_function
 
 import pytest
@@ -294,11 +295,11 @@ def test_weave_func():
 
 
 def test_broken_aspect():
-    raises(AssertionError, aspectlib.weave, None, None)
+    raises(RuntimeError, aspectlib.weave, None, None)
 
 
 def test_weave_empty_target():
-    raises(AssertionError, aspectlib.weave, (), None)
+    raises(RuntimeError, aspectlib.weave, (), None)
 
 
 def test_weave_missing_global(cls=Global):
@@ -972,7 +973,7 @@ def test_weave_unimportable():
     def aspect():
         yield aspectlib.Proceed
 
-    raises(ImportError, aspectlib.weave, "1.2", aspect)
+    raises(ImportError, aspectlib.weave, "asdf1.qwer2", aspect)
 
 
 def test_weave_subclass(Bub=Sub):
@@ -1019,3 +1020,52 @@ def test_unspecified_str():
 
 def test_sentinel():
     assert repr(aspectlib._Sentinel('STUFF', "Means it's some stuff")) == "STUFF: Means it's some stuff"
+
+
+def _internal():
+    pass
+
+if aspectlib.PY3:
+    exec(u"""# encoding: utf8
+
+def ăbc():
+    pass
+
+def test_ăbc():
+    with aspectlib.weave('test_aspectlib.ăbc', mock('stuff')):
+        assert ăbc() == 'stuff'
+""")
+else:
+    def test_py2_invalid_unicode_in_string_target():
+        raises(SyntaxError, aspectlib.weave, 'os.ăa', mock(None))
+        raises(SyntaxError, aspectlib.weave, u'os.ăa', mock(None))
+        raises(SyntaxError, aspectlib.weave, 'os.aă', mock(None))
+        raises(SyntaxError, aspectlib.weave, u'os.aă', mock(None))
+
+
+def test_invalid_string_target():
+    raises(AssertionError, aspectlib.weave, 'inva lid', mock(None))
+    raises(SyntaxError, aspectlib.weave, 'os.inva lid', mock(None))
+    raises(SyntaxError, aspectlib.weave, 'os.2invalid', mock(None))
+    raises(SyntaxError, aspectlib.weave, 'os.some,junk', mock(None))
+    raises(SyntaxError, aspectlib.weave, 'os.some?junk', mock(None))
+    raises(SyntaxError, aspectlib.weave, 'os.some*junk', mock(None))
+
+    with aspectlib.weave('test_aspectlib._internal', mock('stuff')):
+        assert _internal() == 'stuff'
+
+
+def test_list_of_aspects():
+    with aspectlib.weave(module_func, [mock('foobar'), record(call=True)]):
+        assert module_func(1, 2, 3) == 'foobar'
+        assert module_func.calls == [(None, (1, 2, 3), {})]
+
+    with aspectlib.weave(module_func, [mock('foobar', call=True), record(call=True)]):
+        raises(TypeError, module_func, 1, 2, 3)
+        assert module_func.calls == [(None, (1, 2, 3), {})]
+
+def test_list_of_invalid_aspects():
+    raises(AssertionError, aspectlib.weave, module_func, [lambda func: None])
+    raises(TypeError, aspectlib.weave, module_func, [lambda: None])
+    raises(RuntimeError, aspectlib.weave, module_func, [None])
+    raises(RuntimeError, aspectlib.weave, module_func, ['foobar'])
